==> modonomicon-1.19.2-1.5.0-sources.jar: com/klikli_dev/modonomicon/command/SaveUnlocksCommand.java <==
/*
 * SPDX-FileCopyrightText: 2022 klikli-dev
 *
 * SPDX-License-Identifier: MIT
 */

package com.klikli_dev.modonomicon.command;

import com.klikli_dev.modonomicon.api.ModonimiconConstants.I18n.Command;
import com.klikli_dev.modonomicon.book.Book;
import com.klikli_dev.modonomicon.capability.BookUnlockCapability;
import com.klikli_dev.modonomicon.data.BookDataManager;
import com.klikli_dev.modonomicon.network.Networking;
import com.klikli_dev.modonomicon.network.messages.SendUnlockCodeToClientMessage;
import com.mojang.brigadier.CommandDispatcher;
import com.mojang.brigadier.builder.ArgumentBuilder;
import com.mojang.brigadier.context.CommandContext;
import com.mojang.brigadier.exceptions.CommandSyntaxException;
import com.mojang.brigadier.exceptions.DynamicCommandExceptionType;
import com.mojang.brigadier.suggestion.SuggestionProvider;
import net.minecraft.commands.CommandSourceStack;
import net.minecraft.commands.Commands;
import net.minecraft.commands.SharedSuggestionProvider;
import net.minecraft.commands.arguments.ResourceLocationArgument;
import net.minecraft.network.chat.Component;

public class SaveUnlocksCommand implements com.mojang.brigadier.Command<CommandSourceStack> {

    private static final SaveUnlocksCommand CMD = new SaveUnlocksCommand();


    public static ArgumentBuilder<CommandSourceStack, ?> register(CommandDispatcher<CommandSourceStack> dispatcher) {

        return Commands.literal("save_progress")
                .requires(cs -> cs.hasPermission(1))
                .then(Commands.argument("book", ResourceLocationArgument.id())
                        .suggests(ResetBookUnlocksCommand.SUGGEST_BOOK)
                        .executes(CMD));

    }


    @Override
    public int run(CommandContext<CommandSourceStack> context) throws CommandSyntaxException {
        var book = ResetBookUnlocksCommand.getBook(context, "book");

        var code = BookUnlockCapability.getUnlockCodeFor(context.getSource().getPlayer(), book);

        Networking.sendToSplit(context.getSource().getPlayer(), new SendUnlockCodeToClientMessage(code));

        context.getSource().sendSuccess(Component.translatable(Command.SUCCESS_SAVE_PROGRESS, Component.translatable(book.getName())), true);
        return 1;
    }
}

==> modonomicon-1.19.2-1.24.0-sources.jar: com/klikli_dev/modonomicon/command/SaveUnlocksCommand.java <==
/*
 * SPDX-FileCopyrightText: 2022 klikli-dev
 *
 * SPDX-License-Identifier: MIT
 */

package com.klikli_dev.modonomicon.command;

import com.klikli_dev.modonomicon.api.ModonomiconConstants.I18n.Command;
import com.klikli_dev.modonomicon.capability.BookUnlockCapability;
import com.klikli_dev.modonomicon.network.Networking;
import com.klikli_dev.modonomicon.network.messages.SendUnlockCodeToClientMessage;
import com.mojang.brigadier.CommandDispatcher;
import com.mojang.brigadier.builder.ArgumentBuilder;
import com.mojang.brigadier.context.CommandContext;
import com.mojang.brigadier.exceptions.CommandSyntaxException;
import net.minecraft.commands.CommandSourceStack;
import net.minecraft.commands.Commands;
import net.minecraft.commands.arguments.ResourceLocationArgument;
import net.minecraft.network.chat.Component;

public class SaveUnlocksCommand implements com.mojang.brigadier.Command<CommandSourceStack> {

    private static final SaveUnlocksCommand CMD = new SaveUnlocksCommand();


    public static ArgumentBuilder<CommandSourceStack, ?> register(CommandDispatcher<CommandSourceStack> dispatcher) {

        return Commands.literal("save_progress")
                .requires(cs -> cs.hasPermission(1))
                .then(Commands.argument("book", ResourceLocationArgument.id())
                        .suggests(ResetBookUnlocksCommand.SUGGEST_BOOK)
                        .executes(CMD));

    }


    @Override
    public int run(CommandContext<CommandSourceStack> context) throws CommandSyntaxException {
        var book = ResetBookUnlocksCommand.getBook(context, "book");

        var code = BookUnlockCapability.getUnlockCodeFor(context.getSource().getPlayer(), book);

        Networking.sendToSplit(context.getSource().getPlayer(), new SendUnlockCodeToClientMessage(code));

        context.getSource().sendSuccess(Component.translatable(Command.SUCCESS_SAVE_PROGRESS, Component.translatable(book.getName())), true);
        return 1;
    }
}
